@@ -172,22 +172,24 @@ def request_traderjoe_data():
     brate = [getBorrowRate(util, kink1, kink2, multiplierPerSecond,
                            jumpMultiplierPerSecond, baseRatePerSecond, secondsPerYear) for util in UR.USDC]
 
-
+    UR = UR.assign(BTCB_apy=apy_calculator(UR['BTC.B']))
 
     UR = UR.assign(USDC_apy=apy_calculator(UR.USDC))
     UR = UR.assign(USDT_apy=apy_calculator(UR.USDT))
     UR = UR.assign(USDCE_apy=apy_calculator(UR['USDC.E']))
     UR = UR.assign(USDTE_apy=apy_calculator(UR['USDT.E']))
 
-    final_df = pd.merge(UR.copy(),supply_df.copy(), left_index=True, right_index=True)
-    traderjoe_usdc_df = final_df[['USDC_liquidity', 'USDC', 'USDC_apy']].copy()
-    traderjoe_usdt_df = final_df[['USDT_liquidity', 'USDT', 'USDT_apy']].copy()
+    final_df = pd.merge(UR.copy(), supply_df.copy(), left_index=True, right_index=True)
+    traderjoe_usdc_df = final_df[['USDC_liquidity', 'USDC_apy']].copy()
+    traderjoe_usdt_df = final_df[['USDT_liquidity', 'USDT_apy']].copy()
+    traderjoe_btcb_df = final_df[['BTC.B_liquidity', 'BTCB_apy']].copy()
     #    final_df[['USDC.E_liquidity', 'USDC.E', 'USDCE_apy']].copy()
     #    final_df[['USDT.E_liquidity','USDT.E', 'USDTE_apy']].copy()
-    traderjoe_usdc_df = traderjoe_usdc_df.rename(columns = {'USDC_liquidity': 'supply_liquidity', 'USDC_apy':'dapr'})
-    traderjoe_usdt_df = traderjoe_usdt_df.rename(columns = {'USDT_liquidity': 'supply_liquidity', 'USDT_apy':'dapr'})
-    return traderjoe_usdc_df, traderjoe_usdt_df
 
+    traderjoe_usdc_df = traderjoe_usdc_df.rename(columns={'USDC_liquidity': 'supply_liquidity', 'USDC_apy': 'dapr'})
+    traderjoe_usdt_df = traderjoe_usdt_df.rename(columns={'USDT_liquidity': 'supply_liquidity', 'USDT_apy': 'dapr'})
+    traderjoe_btcb_df = traderjoe_btcb_df.rename(columns={'BTC.B_liquidity': 'supply_liquidity', 'BTCB_apy': 'dapr'})
+    return traderjoe_usdc_df, traderjoe_usdt_df, traderjoe_btcb_df
 
 
 def request_samurai_aave_v3_usdc():
@@ -208,6 +210,7 @@ def request_samurai_aave_v3_usdc():
     data_aavev3_usdc_df = pd.DataFrame().from_records(json.loads(x.text))
     data_aavev3_usdc_df['date'] = pd.to_datetime(data_aavev3_usdc_df['timestamp'], unit='ms')
     data_aavev3_usdc_df = data_aavev3_usdc_df.set_index('date')
+    data_aavev3_usdc_df['supply_liquidity'] = data_aavev3_usdc_df['tvl']/(1. + data_aavev3_usdc_df['utilization'])
     return data_aavev3_usdc_df
 
 
@@ -230,6 +233,7 @@ def request_samurai_benqi_usdc():
     data_benqi_usdc_df = pd.DataFrame().from_records(json.loads(x.text))
     data_benqi_usdc_df['date'] = pd.to_datetime(data_benqi_usdc_df['timestamp'], unit='ms')
     data_benqi_usdc_df = data_benqi_usdc_df.set_index('date')
+    data_benqi_usdc_df['supply_liquidity'] = data_benqi_usdc_df['tvl']/(1. + data_benqi_usdc_df['utilization'])
     return data_benqi_usdc_df
 
 
@@ -237,7 +241,7 @@ def request_samurai_benqi_usdc():
 def request_samurai_aavev3_savax():
     #https://yieldsamurai.com/pool/avalanche/0x513c7e3a9c69ca3e22550ef58ac1c0088e918fff
     samurai_url = 'https://yieldsamurai.com/api/pool-historical-data'
-    benqi_savax_payload ={
+    aave_savax_payload ={
         "id": "103079215112",
         "period": 0,
         "range": None,
@@ -248,11 +252,12 @@ def request_samurai_aavev3_savax():
             "utilization"
         ]
     }
-    x = requests.post(samurai_url, json=benqi_savax_payload)
-    data_benqi_savax_df = pd.DataFrame().from_records(json.loads(x.text))
-    data_benqi_savax_df['date'] = pd.to_datetime(data_benqi_savax_df['timestamp'], unit='ms')
-    data_benqi_savax_df = data_benqi_savax_df.set_index('date')
-    return data_benqi_savax_df
+    x = requests.post(samurai_url, json=aave_savax_payload)
+    data_aave_savax_df = pd.DataFrame().from_records(json.loads(x.text))
+    data_aave_savax_df['date'] = pd.to_datetime(data_aave_savax_df['timestamp'], unit='ms')
+    data_aave_savax_df = data_aave_savax_df.set_index('date')
+    data_aave_savax_df['supply_liquidity'] = data_aave_savax_df['tvl']/(1. + data_aave_savax_df['utilization'])
+    return data_aave_savax_df
 
 def request_samurai_benqi_savax():
     #https: // yieldsamurai.com / pool / avalanche / 0xf362fea9659cf036792c9cb02f8ff8198e21b4cb
@@ -272,6 +277,7 @@ def request_samurai_benqi_savax():
     data_benqi_savax_df = pd.DataFrame().from_records(json.loads(x.text))
     data_benqi_savax_df['date'] = pd.to_datetime(data_benqi_savax_df['timestamp'], unit='ms')
     data_benqi_savax_df = data_benqi_savax_df.set_index('date')
+    data_benqi_savax_df['supply_liquidity'] = data_benqi_savax_df['tvl']/(1. + data_benqi_savax_df['utilization'])
     return data_benqi_savax_df
 
 
@@ -293,6 +299,7 @@ def request_samurai_benqi_btcb():
     data_benqi_btcb_df = pd.DataFrame().from_records(json.loads(x.text))
     data_benqi_btcb_df['date'] = pd.to_datetime(data_benqi_btcb_df['timestamp'], unit='ms')
     data_benqi_btcb_df = data_benqi_btcb_df.set_index('date')
+    data_benqi_btcb_df['supply_liquidity'] = data_benqi_btcb_df['tvl']/(1. + data_benqi_btcb_df['utilization'])
     return data_benqi_btcb_df
 
 def request_samurai_aave_v3_btcb():
@@ -313,6 +320,8 @@ def request_samurai_aave_v3_btcb():
     data_aavev3_btcb_df = pd.DataFrame().from_records(json.loads(x.text))
     data_aavev3_btcb_df['date'] = pd.to_datetime(data_aavev3_btcb_df['timestamp'], unit='ms')
     data_aavev3_btcb_df = data_aavev3_btcb_df.set_index('date')
+    data_aavev3_btcb_df['supply_liquidity'] = data_aavev3_btcb_df['tvl']/(1. + data_aavev3_btcb_df['utilization'])
+
     return data_aavev3_btcb_df
 
 
@@ -334,6 +343,7 @@ def request_samurai_aave_v3_usdt():
     data_aavev3_usdt_df = pd.DataFrame().from_records(json.loads(x.text))
     data_aavev3_usdt_df['date'] = pd.to_datetime(data_aavev3_usdt_df['timestamp'], unit='ms')
     data_aavev3_usdt_df = data_aavev3_usdt_df.set_index('date')
+    data_aavev3_usdt_df['supply_liquidity'] = data_aavev3_usdt_df['tvl']/(1. + data_aavev3_usdt_df['utilization'])
     return data_aavev3_usdt_df
 
 def request_samurai_benqi_usdt():
@@ -354,4 +364,5 @@ def request_samurai_benqi_usdt():
     data_benqi_usdt_df = pd.DataFrame().from_records(json.loads(x.text))
     data_benqi_usdt_df['date'] = pd.to_datetime(data_benqi_usdt_df['timestamp'], unit='ms')
     data_benqi_usdt_df = data_benqi_usdt_df.set_index('date')
+    data_benqi_usdt_df['supply_liquidity'] = data_benqi_usdt_df['tvl']/(1. + data_benqi_usdt_df['utilization'])
     return data_benqi_usdt_df
\ No newline at end of file
